@@ -1,4 +1,5 @@
 """Parsers for various forms of data formats."""
+
 import plistlib
 from typing import Any
 
@@ -14,3 +15,8 @@ def decode_plist(data: bytes) -> Any:  # noqa: ANN401
         data = plist_header + data
 
     return plistlib.loads(data)
+
+
+def format_hex_byte(byte: int) -> str:
+    """Format a byte as a two character hex string in uppercase."""
+    return f"{byte:02x}".upper()
